//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Shape/EllipseDisplay.h
//! @brief     Defines EllipseDisplay class
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_SHAPE_ELLIPSEDISPLAY_H
#define BORNAGAIN_GUI_VIEW_SHAPE_ELLIPSEDISPLAY_H

#include "GUI/View/Shape/RectangleBaseDisplay.h"

class EllipseItem;

//! This is a View of ellipse mask (represented by EllipseItem) on GraphicsScene.
//! Given view follows standard QGraphicsScene notations: (x,y) is top left corner.

class EllipseDisplay : public RectangleBaseDisplay {
    Q_OBJECT
public:
    int type() const override { return MaskType::ELLIPSE; }

    explicit EllipseDisplay(EllipseItem* item);

    MaskRoot* parameterizedItem() const override;

private slots:
    void onChangedX() override;
    void onChangedY() override;
    void onPropertyChange() override;

private:
    QPainterPath shape() const override;
    void mouseMoveEvent(QGraphicsSceneMouseEvent* event) override;

    void update_position() override;
    QRectF mask_rectangle() override;
    qreal left() const override;
    qreal right() const override;
    qreal top() const override;
    qreal bottom() const override;

private:
    EllipseItem* m_item;
};

#endif // BORNAGAIN_GUI_VIEW_SHAPE_ELLIPSEDISPLAY_H
